pub fn push_stream_override(s: Arc<CudaStream>) -> StreamOverrideExpand description
Push s as the ambient stream for the current thread until the guard drops.
pub fn push_stream_override(s: Arc<CudaStream>) -> StreamOverridePush s as the ambient stream for the current thread until the guard drops.